@@ -1,5 +1,5 @@
 #' Coerce to a Data Frame
-#' 
+#'
 #' Coerces a BibEntry object to a data.frame, with each row of the data frame being a field present in at least one
 #' entry in the BibEntry object being coerced.
 #' @param x - a BibEntry object
@@ -10,12 +10,12 @@
 #' @export
 #' @return a data.frame object with row names giving the keys, and first column giving entry type.
 #' @seealso \code{\link{BibEntry}}, \code{\link{as.BibEntry}}
-#' @examples 
-#' bib <- list(c(bibtype = "article", key = "mclean2014a", title = "My New Article", 
-#'   author = "Mathew W. McLean", journaltitle = "The Journal", date = "2014-01"), 
-#'   c(bibtype = "article", key = "mclean2014b", volume = 10, title = "My Newer Article", 
-#'   author = "Mathew W. McLean", journaltitle = "The Journal", date = "2014-02"))       
-#' bib <- as.BibEntry(bib)   
+#' @examples
+#' bib <- list(c(bibtype = "article", key = "mclean2014a", title = "My New Article",
+#'   author = "Mathew W. McLean", journaltitle = "The Journal", date = "2014-01"),
+#'   c(bibtype = "article", key = "mclean2014b", volume = 10, title = "My Newer Article",
+#'   author = "Mathew W. McLean", journaltitle = "The Journal", date = "2014-02"))
+#' bib <- as.BibEntry(bib)
 #' as.data.frame(bib)
 as.data.frame.BibEntry <- function(x, row.names = NULL, optional = FALSE, ...){
   col.names <- unique(unlist(fields(x)))
@@ -25,7 +25,7 @@ as.data.frame.BibEntry <- function(x, row.names = NULL, optional = FALSE, ...){
                      stringsAsFactors = FALSE,
                      row.names = make.unique(names(x), sep = "-"))
   colnames(y) <- c('bibtype', col.names)
-       
+
   y[, 1L] <- unlist(x$bibtype)
   not.nulls <- 1L
   for (i in seq_len(n.fields)){
@@ -35,6 +35,8 @@ as.data.frame.BibEntry <- function(x, row.names = NULL, optional = FALSE, ...){
       not.nulls <- !vapply(temp, is.null, FALSE)
 
     if (nom %in% .BibEntryNameList){
+      if (n.entries == 1L)  # #51, needed so mult. names, not treated as mult. entries
+        temp <- list(temp)
       temp <- vapply(temp[not.nulls], format_author, "")
     }else{
       temp <- unlist(temp)
@@ -42,6 +44,6 @@ as.data.frame.BibEntry <- function(x, row.names = NULL, optional = FALSE, ...){
 
     y[not.nulls, nom] <- temp
   }
-  
+
   return(y)
 }
