@@ -69,15 +69,15 @@ format.BibEntry <- function(x, style = .BibOptions$style,
         }, "")
         if (style == "html"){
             res <- sub("<code>([[:print:]]*)</code>", "<a id='bib-\\1'></a>",
-                       res, useBytes = TRUE)
+                       res, useBytes = FALSE)
           res <- if (.bibstyle == "alphabetic" || .bibstyle == "numeric")
                      sub("^<p>([[:print:]]*\\])(</a>)?", "<p>\\1\\2<cite>",
-                         res, useBytes = TRUE)
+                         res, useBytes = FALSE)
                  else if (.bibstyle == "draft")
                      sub("^<p>([[:print:]]*</B>)", "<p>\\1<cite>", res,
-                         useBytes = TRUE)
+                         useBytes = FALSE)
                  else
-                     sub("^<p>", "<p><cite>", res, useBytes = TRUE)
+                     sub("^<p>", "<p><cite>", res, useBytes = FALSE)
           res <- vapply(res, function(x) if (grepl("<cite>", x, useBytes=TRUE))
                         paste0(x, "</cite></p>")
                       else  # XData or Set
